@@ -54,7 +54,6 @@
 #' 4(1):160647.
 #' 
 #' @examples 
-#' # Cypripedium example using blocksize
 #' data(cypdata)
 #' 
 #' sizevector <- c(0, 0, 0, 0, 0, 0, 1, 2.5, 4.5, 8, 17.5)
@@ -96,58 +95,6 @@
 #'   size = c("size3added", "size2added"), supplement = cypsupp2r,
 #'   yearcol = "year2", patchcol = "patchid", indivcol = "individ")
 #'                        
-#' cypmatrix2r$A[[intersect(which(cypmatrix2r$labels$patch == "A"), 
-#'   which(cypmatrix2r$labels$year2 == 2004))]]
-#' 
-#' lambda3(cypmatrix2r)
-#' 
-#' # Cypripedium example using partial repeat patterns with blocksize and part
-#' # explicit variable name cast
-#' data(cypdata)
-#' 
-#' sizevector <- c(0, 0, 0, 0, 0, 0, 1, 2.5, 4.5, 8, 17.5)
-#' stagevector <- c("SD", "P1", "P2", "P3", "SL", "D", "XSm", "Sm", "Md", "Lg",
-#'   "XLg")
-#' repvector <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1)
-#' obsvector <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1)
-#' matvector <- c(0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1)
-#' immvector <- c(0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0)
-#' propvector <- c(1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
-#' indataset <- c(0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1)
-#' binvec <- c(0, 0, 0, 0, 0, 0.5, 0.5, 1, 1, 2.5, 7)
-#' 
-#' cypframe_raw <- sf_create(sizes = sizevector, stagenames = stagevector,
-#'   repstatus = repvector, obsstatus = obsvector, matstatus = matvector,
-#'   propstatus = propvector, immstatus = immvector, indataset = indataset,
-#'   binhalfwidth = binvec)
-#' 
-#' cypraw_v1 <- verticalize3(data = cypdata, noyears = 6, firstyear = 2004,
-#'   patchidcol = "patch", individcol = "plantid", blocksize = 4,
-#'   sizeacol = "Inf2.04", sizebcol = "Inf.04", sizeccol = "Veg.04",
-#'   repstracol = c("Inf.04", "Inf.05", "Inf.06", "Inf.07", "Inf.08", "Inf.09"),
-#'   repstrbcol = c("Inf2.04", "Inf2.05", "Inf2.06", "Inf2.07", "Inf2.08", "Inf2.09"), 
-#'   fecacol = "Pod.04", stageassign = cypframe_raw, stagesize = "sizeadded",
-#'   NAas0 = TRUE, NRasRep = TRUE)
-#' 
-#' cypsupp2r <- supplemental(stage3 = c("SD", "P1", "P2", "P3", "SL", "D", 
-#'     "XSm", "Sm", "SD", "P1"),
-#'   stage2 = c("SD", "SD", "P1", "P2", "P3", "SL", "SL", "SL", "rep",
-#'     "rep"),
-#'   eststage3 = c(NA, NA, NA, NA, NA, "D", "XSm", "Sm", NA, NA),
-#'   eststage2 = c(NA, NA, NA, NA, NA, "XSm", "XSm", "XSm", NA, NA),
-#'   givenrate = c(0.10, 0.20, 0.20, 0.20, 0.25, NA, NA, NA, NA, NA),
-#'   multiplier = c(NA, NA, NA, NA, NA, NA, NA, NA, 0.5, 0.5),
-#'   type =c(1, 1, 1, 1, 1, 1, 1, 1, 3, 3),
-#'   stageframe = cypframe_raw, historical = FALSE)
-#' 
-#' cypmatrix2r <- rlefko2(data = cypraw_v1, stageframe = cypframe_raw, 
-#'   year = "all", patch = "all", stages = c("stage3", "stage2", "stage1"),
-#'   size = c("size3added", "size2added"), supplement = cypsupp2r,
-#'   yearcol = "year2", patchcol = "patchid", indivcol = "individ")
-#'                        
-#' cypmatrix2r$A[[intersect(which(cypmatrix2r$labels$patch == "A"), 
-#'   which(cypmatrix2r$labels$year2 == 2004))]]
-#' 
 #' lambda3(cypmatrix2r)
 "cypdata"
 
@@ -212,8 +159,6 @@
 #'   propstatus = propvector, immstatus = immvector, indataset = indataset,
 #'   binhalfwidth = binvec)
 #' 
-#' cypframe_raw
-#' 
 #' cypraw_v2 <- historicalize3(data = cypvert, patchidcol = "patch", 
 #'   individcol = "plantid", year2col = "year2", sizea2col = "Inf2.2", 
 #'   sizea3col = "Inf2.3", sizeb2col = "Inf.2", sizeb3col = "Inf.3", 
@@ -239,9 +184,6 @@
 #'   size = c("size3added", "size2added"), supplement = cypsupp2r,
 #'   yearcol = "year2", patchcol = "patchid", indivcol = "individ")
 #'   
-#' cypmatrix2r$A[[intersect(which(cypmatrix2r$labels$patch == "A"), 
-#'   which(cypmatrix2r$labels$year2 == 2004))]]
-#' 
 #' lambda3(cypmatrix2r)
 "cypvert"
 
@@ -330,54 +272,6 @@
 #' history of individuals matter? \emph{Ecology} 81(6):1675-1684.
 #' 
 #' @examples
-#' # Lathyrus example using blocksize - when repeated patterns exist in variable
-#' # order
-#' data(lathyrus)
-#' 
-#' sizevector <- c(0, 100, 13, 127, 3730, 3800, 0)
-#' stagevector <- c("Sd", "Sdl", "VSm", "Sm", "VLa", "Flo", "Dorm")
-#' repvector <- c(0, 0, 0, 0, 0, 1, 0)
-#' obsvector <- c(0, 1, 1, 1, 1, 1, 0)
-#' matvector <- c(0, 0, 1, 1, 1, 1, 1)
-#' immvector <- c(1, 1, 0, 0, 0, 0, 0)
-#' propvector <- c(1, 0, 0, 0, 0, 0, 0)
-#' indataset <- c(0, 1, 1, 1, 1, 1, 1)
-#' binvec <- c(0, 100, 11, 103, 3500, 3800, 0.5)
-#' 
-#' lathframe <- sf_create(sizes = sizevector, stagenames = stagevector,
-#'   repstatus = repvector, obsstatus = obsvector, matstatus = matvector,
-#'   immstatus = immvector, indataset = indataset, binhalfwidth = binvec,
-#'   propstatus = propvector)
-#' 
-#' lathvert <- verticalize3(lathyrus, noyears = 4, firstyear = 1988,
-#'   patchidcol = "SUBPLOT", individcol = "GENET", blocksize = 9,
-#'   juvcol = "Seedling1988", sizeacol = "Volume88", repstracol = "FCODE88",
-#'   fecacol = "Intactseed88", deadacol = "Dead1988",
-#'   nonobsacol = "Dormant1988", stageassign = lathframe, stagesize = "sizea",
-#'   censorcol = "Missing1988", censorkeep = NA, censor = TRUE)
-#' 
-#' lathsupp3 <- supplemental(stage3 = c("Sd", "Sd", "Sdl", "Sdl", "Sd", "Sdl", "mat"),
-#'   stage2 = c("Sd", "Sd", "Sd", "Sd", "rep", "rep", "Sdl"),
-#'   stage1 = c("Sd", "rep", "Sd", "rep", "npr", "npr", "Sd"),
-#'   eststage3 = c(NA, NA, NA, NA, NA, NA, "mat"),
-#'   eststage2 = c(NA, NA, NA, NA, NA, NA, "Sdl"),
-#'   eststage1 = c(NA, NA, NA, NA, NA, NA, "NotAlive"),
-#'   givenrate = c(0.345, 0.345, 0.054, 0.054, NA, NA, NA),
-#'   multiplier = c(NA, NA, NA, NA, 0.345, 0.054, NA),
-#'   type = c(1, 1, 1, 1, 3, 3, 1), type_t12 = c(1, 2, 1, 2, 1, 1, 1),
-#'   stageframe = lathframe, historical = TRUE)
-#' 
-#' ehrlen3 <- rlefko3(data = lathvert, stageframe = lathframe, year = "all", 
-#'   stages = c("stage3", "stage2", "stage1"), supplement = lathsupp3,
-#'   yearcol = "year2", indivcol = "individ")
-#' 
-#' ehrlen3mean <- lmean(ehrlen3)
-#' ehrlen3mean$A[[1]]
-#' 
-#' lambda3(ehrlen3mean)
-#' 
-#' # Lathyrus example without blocksize - when no repeated patterns exist in
-#' # variable order and all variables names are specified
 #' data(lathyrus)
 #' 
 #' sizevector <- c(0, 100, 13, 127, 3730, 3800, 0)
@@ -428,106 +322,152 @@
 #' lambda3(ehrlen3mean)
 "lathyrus"
 
-#' Demographic Dataset of \emph{Cypripedium candidum} Population, in Vertical
-#' Format
+#' Demographic Dataset of \emph{Pyrola japonica} and \emph{Pyrola subaphylla}
+#' Populations, in Horizontal Format
 #' 
-#' A dataset containing the states and fates of \emph{Cypripedium candidum} 
-#' (white lady's slipper orchids), family Orchidaceae, from a population in 
-#' Illinois, USA, resulting from monitoring that occurred annually between 2004 
-#' and 2009. Same dataset as \code{cypdata}, but arranged in an ahistorical
-#' vertical format.
+#' A dataset containing the states and fates of \emph{Pyrola japonica} and
+#' \emph{Pyrola subaphylla}, family Ericaceae, from populations in the vicinity
+#' of Mt. Bandai, Fukushima Prefecture, Japan, resulting from monitoring that
+#' occurred annually between 2015 and 2020.
 #' 
 #' @docType data
 #' 
-#' @usage data(cypvert)
+#' @usage data(pyrola)
 #' 
-#' @format A data frame with 77 individuals, 322 rows, and 14 variables. Each
-#' row corresponds to a specific two-year transition for a specific individual.
-#' Variable codes are similar to those for \code{cypdata}, but use \code{.2} to
-#' identify occasion \emph{t} and \code{.3} to identify occasion \emph{t}+1.
+#' @format A data frame with 454 individuals and 57 variables. Each row 
+#' corresponds to an unique individual, and each variable from
+#' \code{sprouted.2015} on refers to the state of the individual in a particular
+#' year.
 #' 
 #' \describe{
-#'   \item{plantid}{A numeric variable giving a unique number to each 
-#'   individual.}
-#'   \item{patch}{A variable refering to patch within the population.}
-#'   \item{X}{An X coordinate for the plant within the population.}
-#'   \item{Y}{A Y coordinate for the plant within the population.}
-#'   \item{censor}{A variable coding for whether the data point is valid. An
-#'   entry of 1 means that it is so.}
-#'   \item{year2}{Year in occasion \emph{t}.}
-#'   \item{Inf2.2}{Number of double inflorescences in occasion \emph{t}.}
-#'   \item{Inf.2}{Number of inflorescences in occasion \emph{t}.}
-#'   \item{Veg.2}{Number of stems without inflorescences in occasion \emph{t}.}
-#'   \item{Pod.2}{Number of fruits in occasion \emph{t}.}
-#'   \item{Inf2.3}{Number of double inflorescences in occasion \emph{t}+1.}
-#'   \item{Inf.3}{Number of inflorescences in occasion \emph{t}+1.}
-#'   \item{Veg.3}{Number of stems without inflorescences in occasion \emph{t}+1.}
-#'   \item{Pod.3}{Number of fruits in occasion \emph{t}+1.}
+#'   \item{species}{String denoting which of the two species the individual
+#'   belongs to.}
+#'   \item{population}{Integer denoting whcih population the individual belongs
+#'   to. Synonymous with species in this dataset.}
+#'   \item{id}{A numeric variable giving a unique number to each 
+#'   individual within each species. Note that numbers are reused among the two
+#'   species.}
+#'   \item{sprouted.2015}{A binomial indicating whether the individual had
+#'   living aboveground tissue observable in the 2015 census.}
+#'   \item{lvs.num.2015}{Number of leaves in 2015.}
+#'   \item{lvs.lng.2015}{Length of largest leaf in 2015.}
+#'   \item{lvs.wdt.2015}{Width of largest leaf in 2015.}
+#'   \item{inf.num.2015}{Number of inflorescences in 2015.}
+#'   \item{inf.lng.tot.2015}{Summed inflorescence length in 2015.}
+#'   \item{flo.tot.2015}{Number of flowers in 2015.}
+#'   \item{frt.tot.2015}{Number of fruits in 2015.}
+#'   \item{sprouted.2016}{A binomial indicating whether the individual had
+#'   living aboveground tissue observable in the 2016 census.}
+#'   \item{lvs.num.2016}{Number of leaves in 2016.}
+#'   \item{lvs.lng.2016}{Length of largest leaf in 2016.}
+#'   \item{lvs.wdt.2016}{Width of largest leaf in 2016.}
+#'   \item{inf.num.2016}{Number of inflorescences in 2016.}
+#'   \item{inf.lng.tot.2016}{Summed inflorescence length in 2016.}
+#'   \item{flo.tot.2016}{Number of flowers in 2016.}
+#'   \item{frt.tot.2016}{Number of fruits in 2016.}
+#'   \item{sprouted.2017}{A binomial indicating whether the individual had
+#'   living aboveground tissue observable in the 2017 census.}
+#'   \item{lvs.num.2017}{Number of leaves in 2017.}
+#'   \item{lvs.lng.2017}{Length of largest leaf in 2017.}
+#'   \item{lvs.wdt.2017}{Width of largest leaf in 2017.}
+#'   \item{inf.num.2017}{Number of inflorescences in 2017.}
+#'   \item{inf.lng.tot.2017}{Summed inflorescence length in 2017.}
+#'   \item{flo.tot.2017}{Number of flowers in 2017.}
+#'   \item{frt.tot.2017}{Number of fruits in 2017.}
+#'   \item{sprouted.2018}{A binomial indicating whether the individual had
+#'   living aboveground tissue observable in the 2018 census.}
+#'   \item{lvs.num.2018}{Number of leaves in 2018.}
+#'   \item{lvs.lng.2018}{Length of largest leaf in 2018.}
+#'   \item{lvs.wdt.2018}{Width of largest leaf in 2018.}
+#'   \item{inf.num.2018}{Number of inflorescences in 2018.}
+#'   \item{inf.lng.tot.2018}{Summed inflorescence length in 2018.}
+#'   \item{flo.tot.2018}{Number of flowers in 2018.}
+#'   \item{frt.tot.2018}{Number of fruits in 2018.}
+#'   \item{sprouted.2019}{A binomial indicating whether the individual had
+#'   living aboveground tissue observable in the 2019 census.}
+#'   \item{lvs.num.2019}{Number of leaves in 2019.}
+#'   \item{lvs.lng.2019}{Length of largest leaf in 2019.}
+#'   \item{lvs.wdt.2019}{Width of largest leaf in 2019.}
+#'   \item{inf.num.2019}{Number of inflorescences in 2019.}
+#'   \item{inf.lng.tot.2019}{Summed inflorescence length in 2019.}
+#'   \item{flo.tot.2019}{Number of flowers in 2019.}
+#'   \item{frt.tot.2019}{Number of fruits in 2019.}
+#'   \item{sprouted.2020}{A binomial indicating whether the individual had
+#'   living aboveground tissue observable in the 2020 census.}
+#'   \item{lvs.num.2020}{Number of leaves in 2020.}
+#'   \item{lvs.lng.2020}{Length of largest leaf in 2020.}
+#'   \item{lvs.wdt.2020}{Width of largest leaf in 2020.}
+#'   \item{inf.num.2020}{Number of inflorescences in 2020.}
+#'   \item{inf.lng.tot.2020}{Summed inflorescence length in 2020.}
+#'   \item{flo.tot.2020}{Number of flowers in 2020.}
+#'   \item{frt.tot.2020}{Number of fruits in 2020.}
 #' }
 #' 
-#' @source Shefferson, R.P., R. Mizuta, and M.J. Hutchings. 2017. Predicting
-#' evolution in response to climate change: the example of sprouting probability
-#' in three dormancy-prone orchid species. \emph{Royal Society Open Science} 
-#' 4(1):160647.
+#' @source Shefferson, R.P., K. Shutoh, and K. Suetsugu. \emph{In review}.
+#' Vegetative dormancy and the evolution of mycoheterotrophy in sister
+#' \emph{Pyrola} species. \emph{Journal of Ecology}.
 #' 
 #' @examples 
-#' data(cypvert)
+#' \donttest{
+#' data(pyrola)
 #' 
-#' sizevector <- c(0, 0, 0, 0, 0, 0, 1, 2.5, 4.5, 8, 17.5)
-#' stagevector <- c("SD", "P1", "P2", "P3", "SL", "D", "XSm", "Sm", "Md", "Lg",
-#'   "XLg")
-#' repvector <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1)
-#' obsvector <- c(0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1)
-#' matvector <- c(0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1)
-#' immvector <- c(0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0)
-#' propvector <- c(1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
-#' indataset <- c(0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1)
-#' binvec <- c(0, 0, 0, 0, 0, 0.5, 0.5, 1, 1, 2.5, 7)
-#' 
-#' cypframe_raw <- sf_create(sizes = sizevector, stagenames = stagevector, 
-#'   repstatus = repvector, obsstatus = obsvector, matstatus = matvector, 
-#'   propstatus = propvector, immstatus = immvector, indataset = indataset,
-#'   binhalfwidth = binvec)
-#' 
-#' cypframe_raw
-#' 
-#' cypraw_v2 <- historicalize3(data = cypvert, patchidcol = "patch", 
-#'   individcol = "plantid", year2col = "year2", sizea2col = "Inf2.2", 
-#'   sizea3col = "Inf2.3", sizeb2col = "Inf.2", sizeb3col = "Inf.3", 
-#'   sizec2col = "Veg.2", sizec3col = "Veg.3", repstra2col = "Inf2.2", 
-#'   repstra3col = "Inf2.3", repstrb2col = "Inf.2", repstrb3col = "Inf.3", 
-#'   feca2col = "Pod.2", feca3col = "Pod.3", repstrrel = 2, 
-#'   stageassign = cypframe_raw, stagesize = "sizeadded", censorcol = "censor",
-#'   censor = FALSE, NAas0 = TRUE, NRasRep = TRUE, reduce = TRUE)
+#' pyrola$species <- as.factor(pyrola$species)
+#' pyrola$population <- as.factor(pyrola$population)
+#' jreg <- pyrola[which(pyrola$population == 1),]
+#' stagevec_jp <- c("P1", "Sdl", "Dorm", "V0nr", "V1nr", "V2nr", "V3nr", "V4nr",
+#'   "V0r", "V1r", "V2r", "V3r", "V4r")
+#' sizeavec_jp <- c(0, 0, 0, 0, 1, 2, 3, 7, 0, 1, 2, 3, 7)
+#' sizeahbin_jp <- c(0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 3.5, 0.5, 0.5, 0.5, 0.5,
+#'   3.5)
+#' repvec_jp <- c(0, 0, 0, 0, rep(0, 4), rep(1, 5))
+#' propvec_jp <- c(1, rep(0, 12))
+#' immvec_jp <- c(1, 1, rep(0, 11))
+#' matvec_jp <- c(0, 0, rep(1, 11))
+#' obsvec_jp <- c(0, 0, 0, rep(1, 10))
+#' indata_jp <- c(0, 0, rep(1, 11))
+#' comments_jp <- c("protocorm", "seedling", "dormant adult", "stump", "1lf nr",
+#'   "2lf nr", "3lf nr", "4+lf nr", "0lf r", "1lf r", "2lf r", "3lf r",
+#'   "4+lf r")
+#' jp_frame <- sf_create(sizes = sizeavec_jp, stagenames = stagevec_jp,
+#'   binhalfwidth = sizeahbin_jp, repstatus = repvec_jp, obsstatus = obsvec_jp,
+#'   indataset = indata_jp, propstatus = propvec_jp, immstatus = immvec_jp,
+#'   matstatus = matvec_jp, comments = comments_jp)
 #'   
-#' cypsupp2r <- supplemental(stage3 = c("SD", "P1", "P2", "P3", "SL", "D", 
-#'     "XSm", "Sm", "SD", "P1"),
-#'   stage2 = c("SD", "SD", "P1", "P2", "P3", "SL", "SL", "SL", "rep",
-#'     "rep"),
-#'   eststage3 = c(NA, NA, NA, NA, NA, "D", "XSm", "Sm", NA, NA),
-#'   eststage2 = c(NA, NA, NA, NA, NA, "XSm", "XSm", "XSm", NA, NA),
-#'   givenrate = c(0.10, 0.20, 0.20, 0.20, 0.25, NA, NA, NA, NA, NA),
-#'   multiplier = c(NA, NA, NA, NA, NA, NA, NA, NA, 0.5, 0.5),
-#'   type =c(1, 1, 1, 1, 1, 1, 1, 1, 3, 3),
-#'   stageframe = cypframe_raw, historical = FALSE)
-#' 
-#' cypmatrix2r <- rlefko2(data = cypraw_v2, stageframe = cypframe_raw, 
-#'   year = "all", patch = "all", stages = c("stage3", "stage2"),
-#'   size = c("size3added", "size2added"), supplement = cypsupp2r,
-#'   yearcol = "year2", patchcol = "patchid", indivcol = "individ")
+#' jhfv <- verticalize3(data = jreg, noyears = 6, firstyear = 2015,
+#'   individcol = "id", blocksize = 8, sizeacol = "lvs.num.2015",
+#'   obsacol = "sprouted.2015", repstracol = "flo.tot.2015",
+#'   repstrbcol = "frt.tot.2015", fecacol = "flo.tot.2015",
+#'   fecbcol = "frt.tot.2015", NAas0 = TRUE, stagesize = "sizea",
+#'   stageassign = jp_frame)
 #'   
-#' cypmatrix2r$A[[intersect(which(cypmatrix2r$labels$patch == "A"), 
-#'   which(cypmatrix2r$labels$year2 == 2004))]]
+#' jp_models_ah <- modelsearch(data = jhfv, stageframe = jp_frame,
+#'   suite = "full", vitalrates = c("surv", "obs", "size", "repst", "fec"),
+#'   fec = c("fec3added", "fec2added"), sizedist = "poisson",
+#'   fecdist = "negbin", fec.trunc = TRUE, historical = FALSE,
+#'   quiet = "partial")
+#' jp_germ <- 0.90
 #' 
-#' lambda3(cypmatrix2r)
-"cypvert"
+#' jp_supp2 <- supplemental(stage3 = c("Sdl", "Dorm", "V0nr", "V1nr", "P1", "Sdl"), 
+#'   stage2 = c("P1", "Sdl", "Sdl", "Sdl", "rep", "rep"),
+#'   eststage3 = c(NA, NA, NA, NA, NA, NA),
+#'   eststage2 = c(NA, NA, NA, NA, NA, NA),
+#'   givenrate = c(0.25, 0.35, 0.10, 0.10, NA, NA), # 0.345, 0.054
+#'   multiplier = c(NA, NA, NA, NA, jp_germ * 0.5, jp_germ * 0.5),
+#'   type = c(1, 1, 1, 1, 3, 3), stageframe = jp_frame, historical = FALSE)
+#' 
+#' jp_ahmpm <- flefko2(year = "all", stageframe = jp_frame,
+#'   supplement = jp_supp2, modelsuite = jp_models_ah, data = jhfv,
+#'   err_check = TRUE)
+#' 
+#' lambda3(jp_ahmpm)
+#' }
+"pyrola"
 
 #' Matrix Set of \emph{Anthyllis vulneraria} Populations in Belgium
 #' 
 #' A \code{lefkoMat} object containing projection matrices developed from
 #' demographic data gathered on nine \emph{Anthyllis vulneraria} populations
-#' from 2003 to 2006 in southwestern Belgium. These matrices were originally
-#' published in Davison et al. (2010; Journal of Eccology 98(2): 255-267).
+#' from 2003 to 2006 in southwestern Belgium.
 #' 
 #' @docType data
 #' 
@@ -559,8 +499,6 @@
 #' @examples
 #' data(anthyllis)
 #' 
-#' summary(anthyllis)
-#' 
 #' lambda3(anthyllis)
 "anthyllis"
 
