@@ -23,7 +23,7 @@ using namespace arma;
 //' @keywords internal
 //' @noRd
 // [[Rcpp::export(.hoffmannofstuttgart)]]
-List hoffmannofstuttgart(arma::mat mainmat, DataFrame indices, int ahstages,
+List hoffmannofstuttgart(arma::mat& mainmat, DataFrame indices, int ahstages,
   StringVector stagenames) {
   arma::uvec stage1 = indices["stage1"];
   arma::uvec stage2 = indices["stage2"];
@@ -34,28 +34,76 @@ List hoffmannofstuttgart(arma::mat mainmat, DataFrame indices, int ahstages,
   arma::mat newmatrix(ahstages, ahstages);
   newmatrix.zeros();
   
+  Rcpp::List condlist (ahstages);
+  
   arma::uvec condidx = find(stage1 == 1);
-  int condlength = condidx.n_elem;
+  int condlength = static_cast<int>(condidx.n_elem);
   
-  for (int i = 0; i < condlength; i++) {
-    if (mainmat(main_index(condidx(i))) > 0) newmatrix(new_index(condidx(i))) = 
-      newmatrix(new_index(condidx(i))) + mainmat(main_index(condidx(i)));
-  }
-  
-  Rcpp::List condlist = List::create(Named("1") = newmatrix);
-  
-  for (int i = 1; i < ahstages; i++) {
+  for (int i = 0; i < ahstages; i++) {
     newmatrix.zeros();
     
     condidx = find(stage1 == (i+1));
-    condlength = condidx.n_elem;
+    condlength = static_cast<int>(condidx.n_elem);
     
     for (int j = 0; j < condlength; j++) {
       if (mainmat(main_index(condidx(j))) > 0) newmatrix(new_index(condidx(j))) = 
         newmatrix(new_index(condidx(j))) + mainmat(main_index(condidx(j)));
     }
     
-    condlist.push_back(newmatrix);
+    condlist(i) = newmatrix;
+  }
+  condlist.names() = stagenames;
+  
+  return (condlist);
+}
+
+//' Core Engine for cond_hmpm()
+//' 
+//' Creates a list of conditional ahistorical matrices in the style noted in
+//' deVries and Caswell (2018).
+//' 
+//' @name .hoffmannofstuttgart_sp
+//' 
+//' @param mainmat Historical matrix in sparse format.
+//' @param indices Data frame including the stages at times \emph{t}-1,
+//' \emph{t}, and \emph{t}+1, asvwell as indices corresponding to elements in
+//' the main historical matrix andvthe conditional matrices to be produced.
+//' @param ahstages The number of stages in the stageframe.
+//' @param stageframe The original stageframe for the input matrices.
+//'
+//' @return A list of ahistorical matrices.
+//' 
+//' @keywords internal
+//' @noRd
+// [[Rcpp::export(.hoffmannofstuttgart_sp)]]
+List hoffmannofstuttgart_sp(arma::sp_mat& mainmat, DataFrame indices,
+  int ahstages, StringVector stagenames) {
+  arma::uvec stage1 = indices["stage1"];
+  arma::uvec stage2 = indices["stage2"];
+  arma::uvec stage3 = indices["stage3"];
+  arma::ivec main_index = indices["main_index"];
+  arma::ivec new_index = indices["new_index"];
+  
+  arma::mat newmatrix(ahstages, ahstages);
+  newmatrix.zeros();
+  
+  Rcpp::List condlist (ahstages);
+  
+  arma::uvec condidx = find(stage1 == 1);
+  int condlength = static_cast<int>(condidx.n_elem);
+  
+  for (int i = 0; i < ahstages; i++) {
+    newmatrix.zeros();
+    
+    condidx = find(stage1 == (i+1));
+    condlength = static_cast<int>(condidx.n_elem);
+    
+    for (int j = 0; j < condlength; j++) {
+      if (mainmat(main_index(condidx(j))) > 0) newmatrix(new_index(condidx(j))) = 
+        newmatrix(new_index(condidx(j))) + mainmat(main_index(condidx(j)));
+    }
+    
+    condlist(i) = newmatrix;
   }
   condlist.names() = stagenames;
   
@@ -91,6 +139,8 @@ List hoffmannofstuttgart(arma::mat mainmat, DataFrame indices, int ahstages,
 //' ahistorical stages.}
 //' \item{labels}{A data frame showing the patch and year of each input full A 
 //' matrix in order.}
+//' \item{err_check}{An optional data frame showing the order of used element
+//' indices to create conditional matrices.}
 //' 
 //' @examples
 //' data(cypdata)
@@ -197,8 +247,8 @@ Rcpp::List cond_hmpm(List hmpm, Nullable<CharacterVector> matchoice = R_NilValue
     matnames(i) = i + 1;
   }
   
-  int ahmpm_rows = ahstages.n_elem;
-  int hmpm_rows = hstage1.n_elem;
+  int ahmpm_rows = static_cast<int>(ahstages.n_elem);
+  int hmpm_rows = static_cast<int>(hstage1.n_elem);
   int hmpm_elems = 2 * ahmpm_rows * ahmpm_rows * ahmpm_rows;
   
   int format_int {0};
@@ -222,11 +272,10 @@ Rcpp::List cond_hmpm(List hmpm, Nullable<CharacterVector> matchoice = R_NilValue
   
   int counter = 0;
   
-  // This next section creates an index of matrix elements in the original matrices
-  // and the new conditional matrices. It must be run on the hstages inputs in
-  // order to handle reduced matrices properly.
+  // Create index of matrix elements in original matrices & conditional matrices
+  // Must be run on hstages inputs to handle reduced matrices properly
   if (format_int == 0) {
-    // This portion handles Ehrlen-format hMPMs
+    // Ehrlen-format hMPMs
     for (int prior = 0; prior < hmpm_rows; prior++) {
       for (int post = 0; post < hmpm_rows; post++) {
         stage1_proxy = hstage1[prior];
@@ -247,7 +296,7 @@ Rcpp::List cond_hmpm(List hmpm, Nullable<CharacterVector> matchoice = R_NilValue
       }
     }
   } else {
-    // This section deals with deVries-format hMPMs
+    // deVries-format hMPMs
     for (int prior = 0; prior < hmpm_rows; prior++) {
       for (int post = 0; post < hmpm_rows; post++) {
         stage1_proxy = hstage1[prior];
@@ -289,45 +338,67 @@ Rcpp::List cond_hmpm(List hmpm, Nullable<CharacterVector> matchoice = R_NilValue
     _["stage2"] = stage2, _["stage3"] = stage3, _["main_index"] = main_index,
     _["new_index"] = new_index);
   
-  // This next line creates the conditional matrices in list form
-  List mats1 = hoffmannofstuttgart(amats(0), loveontherocks, ahmpm_rows, stagenames);
+  // Creates conditional matrices in list form
+  List allout (numofmats);
+  List mats1;
   
   if (iusedmats == 3) {
-    mats1 = hoffmannofstuttgart(fmats(0), loveontherocks, ahmpm_rows, stagenames);
-  } else if (iusedmats == 2) {
-    mats1 = hoffmannofstuttgart(umats(0), loveontherocks, ahmpm_rows, stagenames);
-  } 
-  
-  List allout = List::create(Named("1") = mats1);
-  
-  if (iusedmats == 3) {
-    for (int i = 1; i < numofmats; i++) {
-      mats1 = hoffmannofstuttgart(fmats(i), loveontherocks, ahmpm_rows, stagenames);
-      
-      allout.push_back(mats1);
+    for (int i = 0; i < numofmats; i++) {
+      if (is<NumericMatrix>(fmats(i))) {
+        arma::mat chosen_mat = as<arma::mat>(fmats(i));
+        mats1 = hoffmannofstuttgart(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      } else { 
+        arma::sp_mat chosen_mat = as<arma::sp_mat>(fmats(i));
+        mats1 = hoffmannofstuttgart_sp(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      }
+      allout(i) = mats1;
     }
   } else if (iusedmats == 2) {
-    for (int i = 1; i < numofmats; i++) {
-      mats1 = hoffmannofstuttgart(umats(i), loveontherocks, ahmpm_rows, stagenames);
-      
-      allout.push_back(mats1);
+    for (int i = 0; i < numofmats; i++) {
+      if (is<NumericMatrix>(umats(i))) {
+        arma::mat chosen_mat = as<arma::mat>(umats(i));
+        mats1 = hoffmannofstuttgart(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      } else { 
+        arma::sp_mat chosen_mat = as<arma::sp_mat>(umats(i));
+        mats1 = hoffmannofstuttgart_sp(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      }
+      allout(i) = mats1;
     }
   } else {
-    for (int i = 1; i < numofmats; i++) {
-      mats1 = hoffmannofstuttgart(amats(i), loveontherocks, ahmpm_rows, stagenames);
-      
-      allout.push_back(mats1);
+    for (int i = 0; i < numofmats; i++) {
+      if (is<NumericMatrix>(amats(i))) {
+        arma::mat chosen_mat = as<arma::mat>(amats(i));
+        mats1 = hoffmannofstuttgart(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      } else { 
+        arma::sp_mat chosen_mat = as<arma::sp_mat>(amats(i));
+        mats1 = hoffmannofstuttgart_sp(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      }
+      allout(i) = mats1;
     }
   }
   allout.names() = matnames;
   
-  List panama = List::create(Named("Mcond") = allout, _["hstages"] = hstages,
-    _["ahstages"] = stageframe, _["labels"] = labels);
+  int panama_parts = 4;
+  if (err_c) panama_parts = 5;
+  
+  List panama (panama_parts);
+  
+  panama(0) = allout;
+  panama(1) = hstages;
+  panama(2) = stageframe;
+  panama(3) = labels;
   
   if (err_c) {
-    Rcpp::List morestuff = List::create(_["err_check"] = loveontherocks);
-    panama.push_back(morestuff);
+    panama(4) = loveontherocks;
+    
+    StringVector pan_1 = {"Mcond", "hstages", "ahstages", "labels", "err_check"};
+    panama.names() = pan_1;
+    
+  } else {
+    StringVector pan_2 = {"Mcond", "hstages", "ahstages", "labels"};
+    panama.names() = pan_2;
   }
+  
   panama.attr("class") = "lefkoCondMat";
   
   return panama;
@@ -365,6 +436,8 @@ Rcpp::List cond_hmpm(List hmpm, Nullable<CharacterVector> matchoice = R_NilValue
 //' ahistorical stages.}
 //' \item{labels}{A data frame showing the patch and year of each input full A 
 //' matrix in order.}
+//' \item{err_check}{An optional data frame showing the order of used element
+//' indices to create conditional matrices.}
 //' 
 //' @examples
 //' sizevector <- c(0, 0, 0, 0, 0, 0, 1, 3, 6, 11, 19.5)
@@ -485,7 +558,7 @@ Rcpp::List cond_diff(List lDiff, int ref = 1,
     } else if (usedmats(0) == "F" || usedmats(0) == "f") {
       iusedmats = 3;
     } else {
-      Rcpp::Rcout << "Choice of matrix not recognized. Using A matrices.";
+      Rcpp::Rcout << "Choice of matrix not recognized. Using A matrices.\n";
       iusedmats = 1;
     }
   }
@@ -534,8 +607,8 @@ Rcpp::List cond_diff(List lDiff, int ref = 1,
     matnames(i) = i + 1;
   }
   
-  int ahmpm_rows = ahstages.n_elem;
-  int hmpm_rows = hstage1.n_elem;
+  int ahmpm_rows = static_cast<int>(ahstages.n_elem);
+  int hmpm_rows = static_cast<int>(hstage1.n_elem);
   int hmpm_elems = 2 * ahmpm_rows * ahmpm_rows * ahmpm_rows;
   
   int format_int {0};
@@ -559,11 +632,10 @@ Rcpp::List cond_diff(List lDiff, int ref = 1,
   
   int counter = 0;
   
-  // This next section creates an index of matrix elements in the original matrices
-  // and the new conditional matrices. It must be run on the hstages inputs in
-  // order to handle reduced matrices properly.
+  // Create index of matrix elements in original matrices & conditional matrices
+  // Run on hstages inputs to handle reduced matrices properly
   if (format_int == 0) {
-    // This portion handles Ehrlen-format hMPMs
+    // Ehrlen-format hMPMs
     for (int prior = 0; prior < hmpm_rows; prior++) {
       for (int post = 0; post < hmpm_rows; post++) {
         stage1_proxy = hstage1[prior];
@@ -584,7 +656,7 @@ Rcpp::List cond_diff(List lDiff, int ref = 1,
       }
     }
   } else {
-    // This section deals with deVries-format hMPMs
+    // deVries-format hMPMs
     for (int prior = 0; prior < hmpm_rows; prior++) {
       for (int post = 0; post < hmpm_rows; post++) {
         stage1_proxy = hstage1[prior];
@@ -626,45 +698,67 @@ Rcpp::List cond_diff(List lDiff, int ref = 1,
     _["stage2"] = stage2, _["stage3"] = stage3, _["main_index"] = main_index,
     _["new_index"] = new_index);
   
-  // This next line creates the conditional matrices in list form
-  List mats1 = hoffmannofstuttgart(amats(0), loveontherocks, ahmpm_rows, stagenames);
+  // Create conditional matrices in list form
+  List allout (numofmats);
+  List mats1;
   
   if (iusedmats == 3) {
-    mats1 = hoffmannofstuttgart(fmats(0), loveontherocks, ahmpm_rows, stagenames);
-  } else if (iusedmats == 2) {
-    mats1 = hoffmannofstuttgart(umats(0), loveontherocks, ahmpm_rows, stagenames);
-  } 
-  
-  List allout = List::create(Named("1") = mats1);
-  
-  if (iusedmats == 3) {
-    for (int i = 1; i < numofmats; i++) {
-      mats1 = hoffmannofstuttgart(fmats(i), loveontherocks, ahmpm_rows, stagenames);
-      
-      allout.push_back(mats1);
+    for (int i = 0; i < numofmats; i++) {
+      if (is<NumericMatrix>(fmats(i))) {
+        arma::mat chosen_mat = as<arma::mat>(fmats(i));
+        mats1 = hoffmannofstuttgart(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      } else { 
+        arma::sp_mat chosen_mat = as<arma::sp_mat>(fmats(i));
+        mats1 = hoffmannofstuttgart_sp(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      }
+      allout(i) = mats1;
     }
   } else if (iusedmats == 2) {
-    for (int i = 1; i < numofmats; i++) {
-      mats1 = hoffmannofstuttgart(umats(i), loveontherocks, ahmpm_rows, stagenames);
-      
-      allout.push_back(mats1);
+    for (int i = 0; i < numofmats; i++) {
+      if (is<NumericMatrix>(umats(i))) {
+        arma::mat chosen_mat = as<arma::mat>(umats(i));
+        mats1 = hoffmannofstuttgart(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      } else { 
+        arma::sp_mat chosen_mat = as<arma::sp_mat>(umats(i));
+        mats1 = hoffmannofstuttgart_sp(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      }
+      allout(i) = mats1;
     }
   } else {
-    for (int i = 1; i < numofmats; i++) {
-      mats1 = hoffmannofstuttgart(amats(i), loveontherocks, ahmpm_rows, stagenames);
-      
-      allout.push_back(mats1);
+    for (int i = 0; i < numofmats; i++) {
+      if (is<NumericMatrix>(amats(i))) {
+        arma::mat chosen_mat = as<arma::mat>(amats(i));
+        mats1 = hoffmannofstuttgart(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      } else { 
+        arma::sp_mat chosen_mat = as<arma::sp_mat>(amats(i));
+        mats1 = hoffmannofstuttgart_sp(chosen_mat, loveontherocks, ahmpm_rows, stagenames);
+      }
+      allout(i) = mats1;
     }
   }
   allout.names() = matnames;
   
-  List panama = List::create(Named("Mcond") = allout, _["hstages"] = hstages,
-    _["ahstages"] = stageframe, _["labels"] = labels);
+  int panama_parts = 4;
+  if (err_c) panama_parts = 5;
+  
+  List panama (panama_parts);
+  
+  panama(0) = allout;
+  panama(1) = hstages;
+  panama(2) = stageframe;
+  panama(3) = labels;
   
   if (err_c) {
-    Rcpp::List morestuff = List::create(_["err_check"] = loveontherocks);
-    panama.push_back(morestuff);
+    panama(4) = loveontherocks;
+    
+    StringVector pan_1 = {"Mcond", "hstages", "ahstages", "labels", "err_check"};
+    panama.names() = pan_1;
+    
+  } else {
+    StringVector pan_2 = {"Mcond", "hstages", "ahstages", "labels"};
+    panama.names() = pan_2;
   }
+  
   panama.attr("class") = "lefkoCondDiffMat";
   
   return panama;
